@@ -503,7 +503,7 @@ impl_integer_for_isize!(i16, test_integer_i16);
 impl_integer_for_isize!(i32, test_integer_i32);
 impl_integer_for_isize!(i64, test_integer_i64);
 impl_integer_for_isize!(isize, test_integer_isize);
-#[cfg(feature = "i128")]
+#[cfg(has_i128)]
 impl_integer_for_isize!(i128, test_integer_i128);
 
 macro_rules! impl_integer_for_usize {
@@ -677,7 +677,7 @@ impl_integer_for_usize!(u16, test_integer_u16);
 impl_integer_for_usize!(u32, test_integer_u32);
 impl_integer_for_usize!(u64, test_integer_u64);
 impl_integer_for_usize!(usize, test_integer_usize);
-#[cfg(feature = "i128")]
+#[cfg(has_i128)]
 impl_integer_for_usize!(u128, test_integer_u128);
 
 /// An iterator over binomial coefficients.
